<?php
$translations = array(
	'General_Locale' => 'tr_TR.UTF-8',
	'General_TranslatorName' => 'Fabian Becker, Emre Yazici, Emre Saraçoğlu',
	'General_TranslatorEmail' => 'halfdan@xnorfz.de, dev@yazici.info, hello@emresaracoglu.com',
	'General_EnglishLanguageName' => 'Turkish',
	'General_OriginalLanguageName' => 'Türkçe',
	'General_LayoutDirection' => 'ltr',
	'General_HelloUser' => 'Merhaba, %s!',
	'General_OpenSourceWebAnalytics' => 'Açık kaynak kodlu Web İstatistik Servisi',
	'General_Dashboard' => 'Pano',
	'General_DashboardForASpecificWebsite' => 'Belirli bir websitesi için Pano',
	'General_MultiSitesSummary' => 'Tüm Siteler',
	'General_AllWebsitesDashboard' => 'Tüm Websitelerin Panosu',
	'General_API' => 'API',
	'General_Widgets' => 'Birleşenler',
	'General_Settings' => 'Ayarlar',
	'General_GiveUsYourFeedback' => 'Geri Bildirim Verin!',
	'General_Unknown' => 'Bilinmeyen',
	'General_Never' => 'Asla',
	'General_Required' => '%s gerekli',
	'General_NotValid' => '%s geçerli değil',
	'General_NotDefined' => '%s tanımlı değil',
	'General_Id' => 'No',
	'General_Error' => 'Hata',
	'General_Warning' => 'Uyarı',
	'General_BackToHomepage' => 'Piwik ana sayfasına dönün',
	'General_Yes' => 'Evet',
	'General_No' => 'Hayır',
	'General_Delete' => 'Sil',
	'General_Report' => 'Raporla',
	'General_Reports' => 'Raporlar',
	'General_Edit' => 'Düzenle',
	'General_Download' => 'İndir',
	'General_Upload' => 'Yükle',
	'General_Ok' => 'Tamam',
	'General_Close' => 'Kapat',
	'General_OrCancel' => 'veya %s İptal %s',
	'General_Logout' => 'Oturumu Kapat',
	'General_Username' => 'Kullanıcı adı',
	'General_Description' => 'Açıklama',
	'General_Done' => 'Yapıldı',
	'General_PoweredBy' => 'Altyapı',
	'General_Name' => 'İsim',
	'General_Value' => 'Değer',
	'General_Total' => 'Toplam',
	'General_TotalVisitsActionsRevenue' => '(Toplam: %s ziyaretçi, %s eylem, %s kazanç)',
	'General_AverageOrderValue' => 'Ortalama Sipariş Değeri',
	'General_PurchasedProducts' => 'Satın Alınan Ürünler',
	'General_EcommerceOrders' => 'ETicaret Siparişleri',
	'General_TotalRevenue' => 'Toplam Kazanç',
	'General_ProductRevenue' => 'Ürün Kazancı',
	'General_AveragePrice' => 'Ortalama Fiyat',
	'General_AverageQuantity' => 'Ortalama Ürün Adedi',
	'General_UniquePurchases' => 'Tekil Satın Alımlar',
	'General_ProductConversionRate' => 'Ürün Kuru',
	'General_Quantity' => 'Miktar',
	'General_Price' => 'Fiyat',
	'General_Subtotal' => 'Ara toplam',
	'General_Tax' => 'Vergi',
	'General_Shipping' => 'Teslimat',
	'General_Discount' => 'İndirim',
	'General_Details' => 'Detaylar',
	'General_Default' => 'Varsayılan',
	'General_Visit' => 'Ziyaret',
	'General_FromReferrer' => 'şuradan',
	'General_VisitorIP' => 'Ziyaretçi IP',
	'General_VisitorID' => 'Ziyaretçi ID',
	'General_VisitType' => 'Ziyaretçi Türü',
	'General_DaysSinceLastVisit' => 'Son ziyaretten bu yana geçen gün',
	'General_DaysSinceFirstVisit' => 'İlk ziyaretten bu yana geçen gün',
	'General_DaysSinceLastEcommerceOrder' => 'Son siparişten bu yana geçen gün',
	'General_NumberOfVisits' => 'Ziyaret sayısı',
	'General_NewVisitor' => 'Yeni Ziyaretçi',
	'General_NewVisits' => 'Yeni ziyaret',
	'General_ReturningVisitor' => 'Geri dönen ziyaretçi',
	'General_Visitor' => 'Ziyaretçi',
	'General_Date' => 'Tarih',
	'General_Period' => 'Zaman aralığı',
	'General_ChooseDate' => 'Tarih Seçimi',
	'General_Today' => 'Bugün',
	'General_Yesterday' => 'Gün',
	'General_CurrentWeek' => 'Bu hafta',
	'General_CurrentMonth' => 'Bu ay',
	'General_CurrentYear' => 'Bu yıl',
	'General_DateRange' => 'Tarih aralığı:',
	'General_DateRangeInPeriodList' => 'Tarih aralığı',
	'General_DateRangeFromTo' => '%s tarihinden %s tarihine',
	'General_ApplyDateRange' => 'Tarih Aralığını Uygula',
	'General_InvalidDateRange_js' => 'Geçersiz Tarih Aralığı, Lütfen Tekrar Deneyin',
	'General_DateRangeFrom_js' => 'Buradan',
	'General_DateRangeTo_js' => 'Buraya',
	'General_PreviousDays' => 'Önceki %s gün (bugün hariç)',
	'General_LastDays' => 'Son %s gün (bugün dahil)',
	'General_LoadingData' => 'Veri yükleniyor...',
	'General_Loading_js' => 'Yükleniyor...',
	'General_GoTo' => '%s\'e git',
	'General_Next' => 'İleri',
	'General_Previous' => 'Geri',
	'General_First' => 'İlk',
	'General_Search' => 'Arama',
	'General_Others' => 'Diğerleri',
	'General_Table' => 'Tablo',
	'General_Piechart' => 'Pasta grafik',
	'General_TagCloud' => 'Etiket bulutu',
	'General_VBarGraph' => 'Dikey çubuk grafik',
	'General_View' => 'Göster',
	'General_OpenInNewWindow_js' => 'Yeni pencerede aç',
	'General_SaveImageOnYourComputer_js' => 'Resmi bilgisayarınıza kaydetmek için, resme sağ tıklayıp "Farklı kaydet..." deyin',
	'General_Refresh' => 'Sayfayı yenile',
	'General_Visitors' => 'Ziyaretçiler',
	'General_ExportThisReport' => 'Bu veri setini diğer formatlarda ihraç et',
	'General_ExportAsImage_js' => 'Resim olarak dışa aktar',
	'General_Export' => 'Dışa aktar',
	'General_ParameterMustIntegerBetween' => '%s değeri %s ve %s arasında sayısal bir değer olmalıdır.',
	'General_YourChangesHaveBeenSaved' => 'Değişiklikleriniz kaydedildi.',
	'General_ErrorRequest' => 'Oops… istek sırasında problem meydana geldi, lütfen tekrar deneyin.',
	'General_ColumnNbUniqVisitors' => 'Tekil ziyaretçiler',
	'General_ColumnNbVisits' => 'Ziyaretler',
	'General_ColumnPercentageVisits' => '% Ziyaretler',
	'General_ColumnNbActions' => 'Eylemler',
	'General_NbActions' => 'Eylem Sayısı',
	'General_ColumnMaxActions' => 'Tek ziyarette maksimum eylem',
	'General_ColumnSumVisitLength' => 'Ziyaretçiler tarafından harcanan toplam süre (saniye)',
	'General_ColumnLabel' => 'Etiket',
	'General_ColumnConversionRate' => 'DÖnüşüm Oranı',
	'General_ColumnActionsPerVisit' => 'Ziyaret başına eylemler',
	'General_VisitDuration' => 'Ort. Ziyaret Süresi (saniye cinsinden)',
	'General_ColumnAvgTimeOnSite' => 'Sitede geçirilen ortalama süre',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'Bir ziyaretin ortalama süresi.',
	'General_ColumnVisitDuration' => 'Ziyaret Süresi (saniye bazında)',
	'General_ColumnBounceRate' => 'Hemen çıkma oranı',
	'General_ColumnExitRate' => 'Çıkış oranı',
	'General_ColumnPageviews' => 'Sayfa gösterimleri',
	'General_ColumnPageviewsDocumentation' => 'Bu sayfanın kaç defa ziyaret edildiği',
	'General_ColumnUniquePageviews' => 'Tekil sayfa gösterimleri',
	'General_ColumnBounces' => 'Sıçramalar',
	'General_ColumnUniqueEntrances' => 'Tekil girişler',
	'General_ColumnEntrances' => 'Girişler',
	'General_ColumnEntrancesDocumentation' => 'Bu sayfadan başlayan ziyaret sayısı',
	'General_ColumnExits' => 'Çıkışlar',
	'General_ColumnUniqueExits' => 'Tekil çıkışlar',
	'General_ColumnExitsDocumentation' => 'Bu sayfada biten ziyaret sayısı',
	'General_ColumnAverageTimeOnPage' => 'Sayfada geçirilen ort. süre',
	'General_ColumnValuePerVisit' => 'Ziyaret başına değer',
	'General_ColumnVisitsWithConversions' => 'Sitenize gelen ve (alışveriş, mail listesine kayıt gibi) aktiviteler gösteren ziyaretçileri gör.',
	'General_VisitsWith' => '%s ile Ziyaretler',
	'General_YearsDays' => '%1$s yıl %2$s gün',
	'General_DaysHours' => '%1$s gün %2$s saat',
	'General_HoursMinutes' => '%1$s saat %2$s dak',
	'General_MinutesSeconds' => '%1$s dak %2$ss',
	'General_Seconds' => '%ssn',
	'General_Save' => 'Kaydet',
	'General_ForExampleShort' => 'Örneğin',
	'General_YouMustBeLoggedIn' => 'Bu işleve erişmek için oturumu açmış olmanız gerekmekte.',
	'General_Website' => 'Web sayfası',
	'General_GeneralSettings' => 'Genel Ayarlar',
	'General_NSeconds' => '%s saniye',
	'General_RequiresFlash' => 'Piwik\'in grafikleri gösterebilmesi için Flash gereklidir.',
	'General_GraphHelp' => 'Piwik\'in grafikleri göstermesi hakkında daha fazla bilgi.',
	'General_NoDataForGraph' => 'Bu grafikte veri yok.',
	'General_NoDataForTagCloud' => 'Bu etiket bulutunda veri yok.',
	'General_DisplaySimpleTable' => 'Basit tablo göster',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s işbirlikçi bir projedir. %3$s Eğer Piwik\'den hoşlandıysanız, yardım edebilirsiniz! %4$s Piwik\'e nasıl katılacağınızı%5$s kontrol edin?',
	'General_NewUpdatePiwikX' => 'Yeni Güncelleme: Piwik %s',
	'General_AboutPiwikX' => 'Piwik %s Hakkında',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s kullanılabilir durumda.. %2$s Lütfen şimdi güncelleyin!%3$s (%4$s değişiklikleri%5$s görün).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s mevcut. Lütfen site yöneticisine bildiriniz.',
	'General_BackToPiwik' => 'Piwik\'e geri dön.',
	'General_ClickHere' => 'Daha fazla bilgi için buraya tıklayın.',
	'General_ShortMonth_1' => 'Oca',
	'General_ShortMonth_2' => 'Şub',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Nis',
	'General_ShortMonth_5' => 'May',
	'General_ShortMonth_6' => 'Haz',
	'General_ShortMonth_7' => 'Tem',
	'General_ShortMonth_8' => 'Ağu',
	'General_ShortMonth_9' => 'Eyl',
	'General_ShortMonth_10' => 'Eki',
	'General_ShortMonth_11' => 'Kas',
	'General_ShortMonth_12' => 'Ara',
	'General_LongMonth_1' => 'Ocak',
	'General_LongMonth_2' => 'Şubat',
	'General_LongMonth_3' => 'Mart',
	'General_LongMonth_4' => 'Nisan',
	'General_LongMonth_5' => 'Mayıs',
	'General_LongMonth_6' => 'Haziran',
	'General_LongMonth_7' => 'Temmuz',
	'General_LongMonth_8' => 'Ağustos',
	'General_LongMonth_9' => 'Eylül',
	'General_LongMonth_10' => 'Ekim',
	'General_LongMonth_11' => 'Kasım',
	'General_LongMonth_12' => 'Aralık',
	'General_ShortDay_1' => 'Pzt',
	'General_ShortDay_2' => 'Sa',
	'General_ShortDay_3' => 'Çrş',
	'General_ShortDay_4' => 'Prş',
	'General_ShortDay_5' => 'Cu',
	'General_ShortDay_6' => 'Cmt',
	'General_ShortDay_7' => 'Pzr',
	'General_LongDay_1' => 'Pazartesi',
	'General_LongDay_2' => 'Salı',
	'General_LongDay_3' => 'Çarşamba',
	'General_LongDay_4' => 'Perşembe',
	'General_LongDay_5' => 'Cuma',
	'General_LongDay_6' => 'Cumartesi',
	'General_LongDay_7' => 'Pazar',
	'General_Daily' => 'Günlük',
	'General_Weekly' => 'Haftalık',
	'General_Monthly' => 'Aylık',
	'General_ExceptionDatabaseVersion' => 'Sizin %1$s versiyonunuz %2$s ama Piwik en az %3$s kabul eder.',
	'General_ExceptionIncompatibleClientServerVersions' => '%1$s istemci versiyonunuz %2$s. Ancak bu versiyon %3$s sunucu versiyonu ile uyumlu değildir.',
	'General_ExceptionMissingFile' => 'Kayıp dosya: %s',
	'General_ExceptionFilesizeMismatch' => 'Dosya boyutu uyumsuz: %1$s (beklenen uzunluk: %2$s, bulundu: %3$s)',
	'General_ExceptionFileIntegrity' => 'Bütünlük kontrolü başarısız: %s',
	'General_ExceptionNonceMismatch' => 'Bu formda güvenlik doğrulanamadı.',
	'General_PleaseSpecifyValue' => 'Lütfen \'%s\' için bir değer belirtiniz.',
	'General_ExceptionInvalidDateRange' => '\'%s\' Tarih aralığı geçerli değildir. Aşağidaki format gibi olmalıdır: %s.',
	'General_ExceptionGoalNotFound' => 'Hedef tanımlayıcısı = %s bulunamadı.',
	'General_ExceptionUndeletableFile' => '%s silinemedi',
	'General_ExceptionPrivilege' => 'Bu kaynak %s erişimi gerektirdiğinden erişiminize izin verilmemektedir.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Bu kaynak en az bir web sitesi için %s erişimi gerektirdiğinden erişiminize izin verilmemektedir.',
	'General_ExceptionConfigurationFileNotFound' => 'Yapılandırma dosyası {%s} bulunamadı.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Yapılandırma dosyası {%s} okunamadı. Sitenizi barındıran servis %s özelliğini devre dışı bırakmış olabilir.',
	'General_ExceptionInvalidToken' => 'Güvenlik jetonu geçerli değil.',
	'General_ExceptionLanguageFileNotFound' => '\'%s\' dil dosyası bulunamadı.',
	'General_ExceptionUnableToStartSession' => 'Oturum başlatılamadı.',
	'General_WarningFileIntegritySkipped' => 'Geliştirme Ortamı saptandı. Dosya bütünlük kontrolü gerçekleştirilmedi.',
	'General_WarningFileIntegrityNoManifest' => 'manifest.inc.php dosyası bulunamadığı için dosya bütünlük kontrolü gerçekleştirilemedi.',
	'General_WarningFileIntegrityNoMd5file' => 'md5_file() fonksiyonu bulunamadığı için dosya bütünlük kontrolü tamamlanamadı.',
	'General_FileIntegrityWarningExplanation' => 'Dosya bütünlük kontrolü başarısız oldu ve hatalar raporlandı. Bu durum genellikle Piwik dosyalarının yüklenmesinde oluşan hatalardan meydana gelmektedir. Sorunu çözmek için tüm Piwik dosyalarını sunucunuza tekrar yüklemeniz ve sayfayı yenilemeniz gerekmektedir.',
	'General_UseSMTPServerForEmail' => 'E-posta için SMTP sunucu kullan',
	'General_SmtpServerAddress' => 'SMTP sunucu adresi',
	'General_SmtpPort' => 'SMTP Kapı Numarası',
	'General_AuthenticationMethodSmtp' => 'SMTP için kimlik doğrulama yöntemi',
	'General_SmtpUsername' => 'SMTP kullanıcı adı',
	'General_SmtpPassword' => 'SMTP parolası',
	'General_SmtpEncryption' => 'SMTP şifreleme',
	'General_OptionalSmtpPort' => 'İsteğe bağlıdır. Şifresiz 25 için TLS SMTP ve güvenli bağlantı için SSL SMTP 465',
	'General_OnlyEnterIfRequired' => 'SMTP sunucusu için gerekli olan kullanıcı adını giriniz.',
	'General_OnlyEnterIfRequiredPassword' => 'SMTP sunucusu için gerekli olan şifreyi giriniz.',
	'General_InvalidResponse' => 'Alınan veriler başarısız.',
	'General_ChooseLanguage' => 'Dil seçin',
	'General_ChoosePeriod' => 'Zaman aralığı seçin',
	'General_ChooseWebsite' => 'Web sayfası seçin',
	'General_Language' => 'Dil',
	'General_PleaseUpdatePiwik' => 'Lütfen Piwik\'inizi güncelleyin',
	'General_RequestTimedOut' => 'Veri isteği talebi %s süresi doldu. Lütfen tekrar deneyiniz.',
	'General_Recommended' => '(önerilir)',
	'General_Goal' => 'Hedef',
	'General_Outlink' => 'Dış link',
	'General_Help' => 'Yardım',
	'General_DailySum' => 'günlük toplam',
	'General_AfterEntry' => 'buraya girdikten sonra',
	'General_Metadata' => 'Meta verisi',
	'General_OneVisit' => '1 ziyaret',
	'General_NVisits' => '%s ziyaret',
	'General_OneDay' => '1 gün',
	'General_NDays' => '%s gün',
	'General_MainMetrics' => 'Ana ölçümler',
	'Actions_PluginDescription' => 'Sayfa gösterimleri, dışarı linkler ve indirilenler hakkında raporlar. Dışarı linkler ve indirilenler otomatik.',
	'Actions_Actions' => 'Eylemler',
	'Actions_SubmenuPages' => 'Sayfalar',
	'Actions_SubmenuPagesEntry' => 'Giriş sayfaları',
	'Actions_SubmenuPagesExit' => 'Çıkış sayfaları',
	'Actions_SubmenuPageTitles' => 'Sayfa başlığı',
	'Actions_SubmenuOutlinks' => 'Dışarı linkler',
	'Actions_SubmenuDownloads' => 'İndirilenler',
	'Actions_ColumnClicks' => 'Tıklamalar',
	'Actions_ColumnUniqueClicks' => 'Tekil tıklamalar',
	'Actions_ColumnDownloads' => 'İndirilenler',
	'Actions_ColumnUniqueDownloads' => 'Tekil indirilenler',
	'Actions_ColumnOutlinks' => 'Dış linkler',
	'Actions_ColumnUniqueOutlinks' => 'Tekil dış linkler',
	'Actions_ColumnPageName' => 'Sayfa isimleri',
	'Actions_ColumnPageURL' => 'Sayfa URL\'leri',
	'Actions_ColumnClickedURL' => 'Tıklanan URL\'ler',
	'Actions_ColumnDownloadURL' => 'İndirilen URL\'ler',
	'Actions_ColumnExitPageURL' => 'Çıkış URLsi',
	'Actions_ColumnExitPageTitle' => 'Çıkış URL\'si ismi',
	'AnonymizeIP_PluginDescription' => 'Yerel gizlilik kurallarına uymak için ziyaretçi IP adreslerini gizleyin.',
	'API_PluginDescription' => 'Piwik içerisindeki tüm veriler basit APIlerle kullanılabilmektedir. Bu eklenti Web Istatistiklerinize xml, json, php, csv vb. yollarla erişebilmenizi sağlayan bir erişim noktasıdır.',
	'API_QuickDocumentationTitle' => 'API hızlı belgeler',
	'API_GenerateVisits' => 'Eğer bugün için bir veri yoksa öncelikle %s eklentisiyle biraz veri oluşturabilirsiniz. %s eklentisini aktifleştirin, sonrasında Piwik Yönetim alanından \'Ziyaretçi Oluşturucu\' menüsüne tıklayınız.',
	'API_MoreInformation' => 'Piwik APIsi hakkında daha fazla bilgi için lütfen %s Piwik API Kullanımı %s ve %s Piwik API Referansına %s bakınız.',
	'API_UserAuthentication' => 'Kullanıcı kimlik doğrulaması',
	'API_UsingTokenAuth' => 'Bir script, cron vb içerisinden %s verisi çağırmak isterseniz, %s kimlik doğrulama gerektiren API bağlantılarına %s parametresini eklemelisiniz.',
	'API_KeepTokenSecret' => 'token_auth kullanıcı adı ve şifreniz kadar gizlidir, %s kimseyle paylaşmayınız%s!',
	'API_LoadedAPIs' => '%s API başarılı şekilde yüklendi',
	'CoreAdminHome_PluginDescription' => 'Piwik yönetici arenasi.',
	'CoreAdminHome_MenuGeneralSettings' => 'Genel Ayarlar',
	'CoreAdminHome_Administration' => 'Yönetici',
	'CoreHome_PluginDescription' => 'Web istatistik rapor yapısı.',
	'CoreHome_WebAnalyticsReports' => 'Web Analiz Raporları',
	'CoreHome_ThereIsNoDataForThisReport' => 'Bu rapor için veri yok.',
	'CoreHome_CategoryNoData' => 'Bu kategoride veri yok. "Eklenmiş tüm populasyon" deneyiniz.',
	'CoreHome_ShowJSCode' => 'Eklenecek JavaScript kodu göster',
	'CoreHome_PageOf_js' => '%1$s nin %2$s',
	'CoreHome_PeriodDay' => 'Gün',
	'CoreHome_PeriodWeek' => 'Hafta',
	'CoreHome_PeriodMonth' => 'Ay',
	'CoreHome_PeriodYear' => 'Yıl',
	'CoreHome_PeriodDays' => 'gün',
	'CoreHome_PeriodWeeks' => 'hafta',
	'CoreHome_PeriodMonths' => 'ay',
	'CoreHome_PeriodYears' => 'yıl',
	'CoreHome_DaySu_js' => 'Pa',
	'CoreHome_DayMo_js' => 'Pt',
	'CoreHome_DayTu_js' => 'Sa',
	'CoreHome_DayWe_js' => 'Ça',
	'CoreHome_DayTh_js' => 'Pe',
	'CoreHome_DayFr_js' => 'Cu',
	'CoreHome_DaySa_js' => 'Pt',
	'CoreHome_ShortDay_1_js' => 'Paz',
	'CoreHome_ShortDay_2_js' => 'Pzt',
	'CoreHome_ShortDay_3_js' => 'Sal',
	'CoreHome_ShortDay_4_js' => 'Çar',
	'CoreHome_ShortDay_5_js' => 'Per',
	'CoreHome_ShortDay_6_js' => 'Cum',
	'CoreHome_ShortDay_7_js' => 'Cmt',
	'CoreHome_LongDay_1_js' => 'Pazar',
	'CoreHome_LongDay_2_js' => 'Pazartesi',
	'CoreHome_LongDay_3_js' => 'Salı',
	'CoreHome_LongDay_4_js' => 'Çarşamba',
	'CoreHome_LongDay_5_js' => 'Perşembe',
	'CoreHome_LongDay_6_js' => 'Cuma',
	'CoreHome_LongDay_7_js' => 'Cumartesi',
	'CoreHome_ShortMonth_1_js' => 'Oca',
	'CoreHome_ShortMonth_2_js' => 'Şub',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Nis',
	'CoreHome_ShortMonth_5_js' => 'May',
	'CoreHome_ShortMonth_6_js' => 'Haz',
	'CoreHome_ShortMonth_7_js' => 'Tem',
	'CoreHome_ShortMonth_8_js' => 'Ağu',
	'CoreHome_ShortMonth_9_js' => 'Eyl',
	'CoreHome_ShortMonth_10_js' => 'Eki',
	'CoreHome_ShortMonth_11_js' => 'Kas',
	'CoreHome_ShortMonth_12_js' => 'Ara',
	'CoreHome_MonthJanuary_js' => 'Ocak',
	'CoreHome_MonthFebruary_js' => 'Şubat',
	'CoreHome_MonthMarch_js' => 'Mart',
	'CoreHome_MonthApril_js' => 'Nisan',
	'CoreHome_MonthMay_js' => 'Mayıs',
	'CoreHome_MonthJune_js' => 'Haziran',
	'CoreHome_MonthJuly_js' => 'Temmuz',
	'CoreHome_MonthAugust_js' => 'Ağustos',
	'CoreHome_MonthSeptember_js' => 'Eylül',
	'CoreHome_MonthOctober_js' => 'Ekim',
	'CoreHome_MonthNovember_js' => 'Kasım',
	'CoreHome_MonthDecember_js' => 'Aralık',
	'CorePluginsAdmin_PluginDescription' => 'Eklenti yönetim arabirimi.',
	'CorePluginsAdmin_Plugins' => 'Eklentiler',
	'CorePluginsAdmin_PluginsManagement' => 'Eklenti Yönetimi',
	'CorePluginsAdmin_Plugin' => 'Eklenti',
	'CorePluginsAdmin_Version' => 'Versiyon',
	'CorePluginsAdmin_Status' => 'Statü',
	'CorePluginsAdmin_Action' => 'Eylem',
	'CorePluginsAdmin_PluginHomepage' => 'Eklenti Sayfası',
	'CorePluginsAdmin_Activated' => 'Aktive edildi',
	'CorePluginsAdmin_Active' => 'Aktif',
	'CorePluginsAdmin_Inactive' => 'Pasif',
	'CorePluginsAdmin_Deactivate' => 'Devre dışı',
	'CorePluginsAdmin_Activate' => 'Aktive et',
	'CorePluginsAdmin_MenuPlugins' => 'Eklentiler',
	'CoreUpdater_PluginDescription' => 'Piwik güncelleme mekanizması',
	'CoreUpdater_UpdateTitle' => 'Güncelle',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Veritabanı güncellemesi gerekiyor',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik veritabanınız güncel değil, ve devam etmeden önce güncellenmesi gerekiyor.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik veritabanı %1$s versiyonundan  %2$s versiyonuna güncellenecektir.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Aşağıdaki eklentiler güncellenecektir: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Büyük Piwik güncellemesi için önemli not',
	'CoreUpdater_UpgradePiwik' => 'Piwik\'i güncelle',
	'CoreUpdater_WarningMessages' => 'Uyarı mesajı:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Eklenti güncellenirken hata meydana geldi:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Aşağıdaki eklentileri otomatik olarak devre dışı bıraktık: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik başarıyla güncellendi!',
	'CoreUpdater_ContinueToPiwik' => 'Piwik\'e devam et',
	'CoreUpdater_UpdateAutomatically' => 'Otomatik Güncelleme',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Piwik\'i güncellemek için yeni bir sürümü mevcut',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Otomatik olarak %s versiyonuna güncelleyebilirsiniz veya paketi indirip elle kurabilirsiniz:',
	'CoreUpdater_DownloadX' => 'İndir %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik Tek Tık Güncellemesi iptal edildi. Eğer aşağıdali hatayı düzeltemiyorsanız, Piwik\'i elle güncellemeniz gerekmektedir. Başlamak için %1$s lütfen Güncelleme Dökümanını %3$skontrol edin!%2$s',
	'CoreUpdater_DownloadingUpdateFromX' => 'Güncelleme %sdan indiriliyor',
	'CoreUpdater_UnpackingTheUpdate' => 'Güncelleme dosyaları açılıyor',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Güncelleme dosyaları doğrulanıyor',
	'CoreUpdater_InstallingTheLatestVersion' => 'Son versiyon yükleniyor',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik başarıyla güncellendi!',
	'CoreUpdater_EmptyDatabaseError' => 'Veritabanı %s boş. Yapılandırma dosyanızı değiştirmeniz veya silmeniz gerekmektedir.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Piwik versiyonunuz %s günceldir.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Uyumsuz arşiv: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Boş arşiv.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arşiv tamamlanmadı: bazı dosyalar kayıp (ör. %s).',
	'Dashboard_PluginDescription' => 'Web istatistik panonuz. Panonuzu özelleştirebilirsiniz: yeni widget ekleyebilir, bileşen ayarlarınızı değiştirebilirsiniz. Her kullanıcı kendi panosuna ulaşır.',
	'Dashboard_Dashboard' => 'Pano',
	'Dashboard_DeleteWidgetConfirm' => 'Bu Bileşenı panodan silmek istediğinize emin misiniz?',
	'Dashboard_SelectWidget' => 'Panoya eklemek için bileşen seçiniz.',
	'Dashboard_AddPreviewedWidget_js' => 'Görüntülenen Bileşenı panoya ekleyin.',
	'Dashboard_WidgetPreview_js' => 'Bileşen görünümü',
	'Dashboard_Close_js' => 'Kapat',
	'Dashboard_Maximise_js' => 'Maksimize',
	'Dashboard_TitleWidgetInDashboard_js' => 'Bileşen zaten panoda.',
	'Dashboard_TitleClickToAdd_js' => 'Panoya gitmek için tıklayın',
	'Dashboard_LoadingWidget_js' => 'Bileşen yükleniyor, lütfen bekleyin...',
	'Dashboard_WidgetNotFound_js' => 'Bileşen bulunamadı',
	'DBStats_PluginDescription' => 'Bu eklenti Piwik tabloları ile MySQL veritabanı kullanım raporu.',
	'DBStats_DatabaseUsage' => 'Veritabanı kullanımı',
	'DBStats_MainDescription' => 'Piwik tüm web istatistiklerinizi MySQL veritabanında saklar. Piwik tabloları %s kullanıyor.',
	'DBStats_Table' => 'Tablo',
	'DBStats_RowCount' => 'Satır sayısı',
	'DBStats_DataSize' => 'Veri boyutu',
	'DBStats_IndexSize' => 'Dizin boyutu',
	'DBStats_TotalSize' => 'Toplam boyut',
	'ExampleAPI_PluginDescription' => 'Örnek Eklenti:Özel bir kodlama bilmeden, verilerinizi değişik formatlarda dışarı aktarabilmek için kendi oluşturacağınız eklentinize nasıl bir API oluşturacaksınız?',
	'ExampleFeedburner_PluginDescription' => 'Örnek Eklenti: Sizin Feedburner aboneliğiniz Pano\'da nasil bir birleşen olarak gösterilecek?',
	'ExampleRssWidget_PluginDescription' => 'Örnek Eklenti: RSS beslemesini okuyan bir eklentiyi nasıl oluştururuz?',
	'ExampleUI_PluginDescription' => 'Örnek Eklenti: Bu eklenti Piwik arayüzü ile nasıl çalışacağınızı gösterir: tablo yaratmak, grafikler, vs.',
	'Feedback_PluginDescription' => 'Piwik takımına geribildirimlerinizi gönderin. Düşüncelerinizi ve önerilerinizi paylaşın!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Hata raporu veya özellik öneriniz mi var?',
	'Feedback_ViewAnswersToFAQ' => '%sSık sorulan soruların%s yanıtlarını göster',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Neden sitemin ziyaretleri izlenmiyor?',
	'Feedback_HowToExclude' => 'Kendi ziyaretlerimi nasıl hariç tutarım?',
	'Feedback_WhyWrongCountry' => 'Neden Piwik benim ziyaretlerimi yanlış ülkede gösteriyor?',
	'Feedback_HowToAnonymizeIP' => 'Ziyaretçilerimin IP adreslerini veritabanımda nasıl gizlerim?',
	'Feedback_VisitTheForums' => '%sForumları%s ziyaret edin',
	'Feedback_LearnWaysToParticipate' => '%sOrtak olabileceğiniz%s tüm yolları öğrenin',
	'Feedback_SpecialRequest' => 'Piwik takımına özel bir sorunuz var mı?',
	'Feedback_ContactThePiwikTeam' => 'Piwik takımıyla bağlantı kurun!',
	'Feedback_IWantTo' => 'İstiyorum:',
	'Feedback_CategoryShareStory' => 'Piwik başarı hikayeleri paylaşın',
	'Feedback_CategorySponsor' => 'Piwik\'e sponsor olun',
	'Feedback_CategorySecurity' => 'Güvenlik raporu bildirin',
	'Feedback_MyEmailAddress' => 'E-posta adresim:',
	'Feedback_MyMessage' => 'Mesajım:',
	'Feedback_DetailsPlease' => '(lütfen detayları ekleyin)',
	'Feedback_SendFeedback' => 'Geribildirim Yollayın',
	'Feedback_ManuallySendEmailTo' => 'Lütfen mesajınızı elle yollayın',
	'Feedback_MessageSent' => 'Mesajınız Piwik takımına iletilmiştir.',
	'Feedback_ThankYou' => 'Piwik\'i daha iyi yapmamıza yardım ettiğiniz için teşekkür ederiz!',
	'Feedback_ThePiwikTeam' => 'Piwik Takımı',
	'Feedback_ExceptionBodyLength' => 'Mesajınız en az %s karakter uzunluğunda olmalı',
	'Feedback_ExceptionNoUrls' => 'Spam mesajlardan kaçınmak için mesajınız URL içeremez.',
	'Goals_Goals' => 'Goals',
	'Goals_GoalsOverview' => 'Goals Genel bakış',
	'Goals_GoalsManagement' => 'Goals Yönetimi',
	'Goals_GoalX' => 'Hedef \'%s\'',
	'Goals_GoalConversion' => 'Hedef dönüşümü',
	'Goals_Conversions' => '\'%s\' dönüşümleri',
	'Goals_ConversionRate' => '\'%s\' dönüşüm oranları',
	'Goals_AddNewGoal' => 'Yeni Hedef Ekle',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sYeni Hedef ekle%s veya Mevcut Hedefleri %sDüzenle%s',
	'Goals_AddGoal_js' => 'Hedef Ekle',
	'Goals_UpdateGoal_js' => 'Hedef Güncelle',
	'Goals_DeleteGoalConfirm_js' => '\'%s\' Hedefini silme konusunda emin misiniz?',
	'Goals_CreateNewGOal' => 'Yeni Hedef yarat',
	'Goals_ViewAndEditGoals' => 'Göster ve Hedef\'lerı Düzenle',
	'Goals_GoalName' => 'Hedef İsmi',
	'Goals_WhereThe' => 'Buraya',
	'Goals_Manually' => 'Manuel',
	'Goals_Download' => 'Dosya İndir',
	'Goals_Optional' => '(opsiyonel)',
	'Goals_Contains' => '\'%s\' içeren',
	'Goals_Pattern' => 'Model',
	'Installation_Installation' => 'Yükleme',
	'Installation_InstallationStatus' => 'Yükleme durumu',
	'Installation_PercentDone' => '%s %% tamamlandı',
	'Installation_DatabaseSetup' => 'Veritabanı Yüklemesi',
	'Installation_DatabaseSetupServer' => 'Veritabanı Sunucusu',
	'Installation_DatabaseSetupLogin' => 'Giriş',
	'Installation_DatabaseSetupPassword' => 'Şifre',
	'Installation_DatabaseSetupDatabaseName' => 'Veritabanı adı',
	'Installation_DatabaseSetupTablePrefix' => 'Tablo öneki',
	'Installation_DatabaseCheck' => 'Veritabanı kontrol',
	'Installation_DatabaseServerVersion' => 'Veritabanı sunucu versiyonu',
	'Installation_DatabaseClientVersion' => 'Veritabanı istemci versiyonu',
	'Installation_DatabaseCreation' => 'Veritabaı oluşturma',
	'Installation_LargePiwikInstances' => 'Büyük Piwik örnekleri için yardım',
	'Installation_JsTag' => 'JavaSript etiketi',
	'Installation_JsTagArchivingHelp' => 'Çok trafiğe sahip siteler, Piwik\'in daha hızlı çalışabilmesi için <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">Otomatik Arşivleme nasıl kurulur?</a> sayfasını inceleyiniz.',
	'Installation_Congratulations' => 'Tebrikler',
	'Installation_CongratulationsHelp' => '<p>Tebrikler! Piwik Başarıyla kuruldu.</p><p>JavaScript kodunu sayfalarınıza yerleştirdiğinizden emin olun ve ilk ziyaretçilerinizi beklemeye başlayın!</p>',
	'Installation_ContinueToPiwik' => 'Piwik\'e devam et',
	'Installation_SetupWebsite' => 'Web sitesi ekle',
	'Installation_SetupWebSiteName' => 'Web site adı',
	'Installation_SetupWebSiteURL' => 'Web site adresi',
	'Installation_SetupWebsiteError' => 'Web site eklenirken bir sorun oluştu.',
	'Installation_SetupWebsiteSetupSuccess' => 'Web site %s başarıyla eklendi.',
	'Installation_SuperUserLogin' => 'Süper kullanıcı giriş',
	'Installation_Password' => 'Şifre',
	'Installation_PasswordRepeat' => 'Şifre (tekrar)',
	'Installation_Email' => 'eposta',
	'Installation_SecurityNewsletter' => 'Piwik yükseltmeleri ve güvenlik uyarılarını bana eposta ile bildir.',
	'Installation_CommunityNewsletter' => 'Yeni eklentiler, yeni özellikler gibi güncellemeleri bana eposta ile bildir.',
	'Installation_PasswordDoNotMatch' => 'Girilen şifreler aynı değil.',
	'Installation_Requirements' => 'Piwik gereklilikleri',
	'Installation_Optional' => 'Opsiyonel',
	'Installation_Legend' => 'Gösterge',
	'Installation_Extension' => 'eklenti',
	'Installation_SystemCheck' => 'Sistem kontrolü',
	'Installation_SystemCheckPhp' => 'PHP versiyonu',
	'Installation_SystemCheckExtensions' => 'Gerekli diğer eklentiler',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik mysqli eklentisi ya da PDO ve pdo_mysql eklentilerine ihtiyaç duyar.',
	'Installation_SystemCheckMemoryLimit' => 'Hafıza limiti',
	'Installation_SystemCheckFunctions' => 'Gerekli fonksiyonlar',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckFileIntegrity' => 'Dosya bütünlüğü',
	'Installation_SystemCheckError' => 'Bir hata oluştu. Devam edebilmek için hatayı gidermelisiniz.',
	'Installation_SystemCheckWarning' => 'Piwik normal olarak çalışacaktır ancak bazı özellikler eksik olacak.',
	'Installation_Tables' => 'Tablolar oluşturuluyor',
	'Installation_Welcome' => 'Hoşgeldiniz!',
	'Live_PluginDescription' => 'Ziyaretçilerinizi gözleyin, canlı, gerçek zamanlı!',
	'Live_LinkVisitorLog' => 'Ayrıntılı ziyaretçi kayitlari',
	'Live_Actions' => 'Eylemler',
	'Live_Action' => 'Eylem',
	'Live_VisitorLog' => 'Ziyaretçi kayıtları',
	'Live_Time' => 'Zaman',
	'Live_Referrer_URL' => 'Yönlendirme Siteleri',
	'Live_LastMinutes' => 'Son %s dakika',
	'Live_GoalType' => 'Tür',
	'Live_GoalRevenue' => 'Gelir',
	'Live_GoalDetails' => 'Ayrıntılar',
	'Login_LoginPasswordNotCorrect' => 'Kullanıcı adı & Şifre yanlış',
	'Login_Password' => 'Şifre',
	'Login_PasswordRepeat' => 'Şifre (Tekrar)',
	'Login_ChangePassword' => 'Şifre değiştir',
	'Login_LoginOrEmail' => 'Giriş veya E-posta',
	'Login_RememberMe' => 'Beni Hatırla',
	'Login_LogIn' => 'Oturum aç',
	'Login_Logout' => 'Oturumu kapat',
	'Login_LostYourPassword' => 'Şifrenizi mi unuttunuz?',
	'Login_RemindPassword' => 'Parola sıfırlama gönder',
	'Login_PasswordResetToken' => 'Parola sıfırlama kodu',
	'Login_PasswordReminder' => 'Lütfen kullanıcı adınızı veya e-posta adresinizi giriniz. Şifrenizi sıfırlamak için bilgi e-postası alacaksınız.',
	'Login_PasswordsDoNotMatch' => 'Şifre eşleşmedi',
	'Login_PasswordSuccessfullyChanged' => 'Şifre başarıyla değiştirildi!',
	'Login_InvalidUsernameEmail' => 'Geçersiz kullanıcı adı ve/veya e-posta adresi',
	'Login_InvalidOrExpiredToken' => 'Güvenlik kodu yanlış yada süresi dolmuş.',
	'Login_MailTopicPasswordRecovery' => 'Şifre kurtarma',
	'Login_PasswordSent' => 'Sizin parolanızın sıfırlama bilgilendirmesi gönderildi. Lütfen e-postanızı kontrol ediniz.',
	'Provider_PluginDescription' => 'Ziyaretciden Sağlayıcının Rapoarları',
	'Provider_WidgetProviders' => 'Sağlayıcılar',
	'Provider_ColumnProvider' => 'Sağlayıcı',
	'Provider_SubmenuLocationsProvider' => 'Konumlar & Sağlayıcı',
	'SecurityInfo_Security' => 'Güvenlik',
	'SecurityInfo_SecurityInformation' => 'PHP Güvenlik Bilgilendirmesi',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Sonuç',
	'SEO_SeoRankings' => 'SEO Sıralamaları',
	'SEO_AlexaRank' => 'Alexa Sırası',
	'SEO_DomainAge' => 'Alan Ad Yaşı',
	'SEO_Rank' => 'Sıralama',
	'SEO_Backlinks' => 'Dönünen Linkler',
	'SEO_Pages' => 'Sayfalar',
	'SEO_SEORankingsFor' => '\'%s\'için SEO Sıralama',
	'SitesManager_Sites' => 'Websiteler',
	'SitesManager_WebsitesManagement' => 'Website Yönetimleri',
	'SitesManager_MainDescription' => 'Websitelerinizin Web Analizi için raporara ihtiyaçı vardir. Website ekleme, güncelleme, kaldirma ve sayfalarınızın içindeki JavaScript Kodunu görebilirsiniz.',
	'SitesManager_JsTrackingTag' => 'JavaScript Takip Kodu',
	'SitesManager_JsTrackingTagHelp' => 'Burada tüm sayfalarınıza ekleyebilieceğiniz JavaScript kodudur.',
	'SitesManager_ShowTrackingTag' => 'Takip kodunu göster',
	'SitesManager_NoWebsites' => 'Yönetmek için bir websitesi yok.',
	'SitesManager_AddSite' => 'Websitesi ekle',
	'SitesManager_NotFound' => 'Hiçbir web sitesi bulunamadı',
	'SitesManager_MenuSites' => 'Websiteler',
	'SitesManager_DeleteConfirm_js' => '\'%s\' Websitesini silmekten emin misiniz?',
	'SitesManager_ExceptionNoUrl' => 'Websitesi için en az bir URL belirtmek zorundasiniz.',
	'SitesManager_ExceptionEmptyName' => 'Web sitesi adı boş olamaz.',
	'SitesManager_ExceptionInvalidUrl' => '\'%s\' site URL\'si geçersizdir.',
	'SitesManager_ExceptionInvalidTimezone' => '"%s" saat dilimi geçersiz. Lütfen saat dilimi giriniz.',
	'SitesManager_ExcludedIps' => 'Hariç Tutulan IP\'ler',
	'SitesManager_GlobalListExcludedIps' => 'IP\'ler Hariç',
	'SitesManager_ExcludedParameters' => 'Hariç Birakılan Parametreler',
	'SitesManager_YourCurrentIpAddressIs' => 'Şuan ki IP numaranız %s',
	'SitesManager_SelectACity' => 'Şehir seçiniz',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Sizinle aynı zaman dilimini paylaşan bir şehir seçiniz.',
	'SitesManager_AdvancedTimezoneSupportNotFound' => 'Gelişmiş saat dilimini sizin PHP\'niz desteklemiyor. (Desteklenen PHP>=5.2) Siz manuel şekilde UTC ayarlayabilirsiniz.',
	'SitesManager_UTCTimeIs' => 'UTC zamani \'%s\'',
	'SitesManager_Timezone' => 'Saat dilimi',
	'SitesManager_GlobalWebsitesSettings' => 'Global websitelerin ayarlari',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Yeni websiteler için saat dilimi',
	'SitesManager_SelectDefaultTimezone' => 'Ekleyeceğiniz yeni websitelerin varsayılan saat dilimini seçiniz.',
	'SitesManager_Currency' => 'Para Birimi',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'Para birim simgesi Goals yanında gösterilir.',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Yeni websiteler için varsayılan para birimi',
	'SitesManager_SelectDefaultCurrency' => 'Ekleyeceğiniz websitelerin varsayılan para birimini seçiniz.',
	'TranslationsAdmin_PluginDescription' => 'Sizin dilinizde konuşmak için Piwik yardım edebilirsiniz.',
	'TranslationsAdmin_MenuTranslations' => 'Çeviriler',
	'TranslationsAdmin_MenuLanguages' => 'Diller',
	'TranslationsAdmin_LanguageCode' => 'Dil kodu',
	'TranslationsAdmin_Plugin' => 'Eklenti',
	'TranslationsAdmin_Definition' => 'Tanım',
	'TranslationsAdmin_DefaultString' => 'Varsayılan dizi (İngilizce)',
	'TranslationsAdmin_Translations' => 'Çeviriler',
	'TranslationsAdmin_FixPermissions' => 'Lütfen sistem dosyalarının izinlerini düzeltin',
	'TranslationsAdmin_AddLanguage' => 'Dil ekle',
	'TranslationsAdmin_Export' => 'Sistemden dili dışarı çıkar',
	'TranslationsAdmin_Import' => 'Sisteme dişardan dil ekle',
	'UserCountry_Country' => 'Ülke',
	'UserCountry_Continent' => 'Kıta',
	'UserCountry_Location' => 'Konum',
	'UserCountry_SubmenuLocations' => 'Konumlar',
	'UserCountry_WidgetCountries' => 'Ziyaretçi ülkeleri',
	'UserCountry_country_ac' => 'Ascension Adası',
	'UserCountry_country_ad' => 'Andora',
	'UserCountry_country_ae' => 'Birleşik Arap Emirlikleri',
	'UserCountry_country_af' => 'Afganistan',
	'UserCountry_country_ag' => 'Antigua ve Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Arnavutluk',
	'UserCountry_country_am' => 'Ermenistan',
	'UserCountry_country_an' => 'Hollanda Antilleri',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktika',
	'UserCountry_country_ar' => 'Arjantin',
	'UserCountry_country_as' => 'Amerikan Samoası',
	'UserCountry_country_at' => 'Avusturya',
	'UserCountry_country_au' => 'Avustralya',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Åland',
	'UserCountry_country_az' => 'Azerbaycan',
	'UserCountry_country_ba' => 'Bosna-Hersek',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladeş',
	'UserCountry_country_be' => 'Belçika',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaristan',
	'UserCountry_country_bh' => 'Bahreyn',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Burundi',
	'UserCountry_country_bl' => 'Saint Barthélemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruney',
	'UserCountry_country_bo' => 'Bolivya',
	'UserCountry_country_br' => 'Brezilya',
	'UserCountry_country_bs' => 'Bahama',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet Adası',
	'UserCountry_country_bw' => 'Botsvana',
	'UserCountry_country_by' => 'Beyaz Rusya',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Cocos Adaları',
	'UserCountry_country_cd' => 'Demokratik Kongo Cumhuriyeti',
	'UserCountry_country_cf' => 'Orta Afrika Cumhuriyeti',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'İsviçre',
	'UserCountry_country_ci' => 'Fildişi Sahilleri',
	'UserCountry_country_ck' => 'Cook Adaları',
	'UserCountry_country_cl' => 'Şili',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Çin',
	'UserCountry_country_co' => 'Kolombiya',
	'UserCountry_country_cp' => 'Clipperton Adası',
	'UserCountry_country_cr' => 'Kosta Rika',
	'UserCountry_country_cs' => 'Sırbistan-Karadağ',
	'UserCountry_country_cu' => 'Küba',
	'UserCountry_country_cv' => 'Yeşil Burun',
	'UserCountry_country_cx' => 'Christmas Adası',
	'UserCountry_country_cy' => 'Kıbrıs',
	'UserCountry_country_cz' => 'Çek Cumhuriyeti',
	'UserCountry_country_de' => 'Almanya',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Cibuti',
	'UserCountry_country_dk' => 'Danimarka',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominik Cumhuriyeti',
	'UserCountry_country_dz' => 'Cezayir',
	'UserCountry_country_ec' => 'Ekvador',
	'UserCountry_country_ee' => 'Estonya',
	'UserCountry_country_eg' => 'Mısır',
	'UserCountry_country_eh' => 'Batı Sahra',
	'UserCountry_country_er' => 'Eritre',
	'UserCountry_country_es' => 'İspanya',
	'UserCountry_country_et' => 'Etiyopya',
	'UserCountry_country_eu' => 'Avrupa Birliği',
	'UserCountry_country_fi' => 'Finlandiya',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Adaları',
	'UserCountry_country_fm' => 'Mikronezya Federal Devletleri',
	'UserCountry_country_fo' => 'Faroe Adaları',
	'UserCountry_country_fr' => 'Fransa',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Büyük Britanya',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Gürcistan',
	'UserCountry_country_gf' => 'Fransız Guyanası',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Gana',
	'UserCountry_country_gi' => 'Cebelitarık',
	'UserCountry_country_gl' => 'Grönland',
	'UserCountry_country_gm' => 'Gambiya',
	'UserCountry_country_gn' => 'Gine',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Ekvator Ginesi',
	'UserCountry_country_gr' => 'Yunanistan',
	'UserCountry_country_gs' => 'Güney Georgia ve Güney Sandwich Adaları',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hr' => 'Hırvatistan',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Macaristan',
	'UserCountry_country_ic' => 'Canary Adaları',
	'UserCountry_country_id' => 'Endonezya',
	'UserCountry_country_ie' => 'İrlanda',
	'UserCountry_country_il' => 'İsrail',
	'UserCountry_country_im' => 'Man Adası',
	'UserCountry_country_in' => 'Hindistan',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'İran',
	'UserCountry_country_is' => 'İzlanda',
	'UserCountry_country_it' => 'İtalya',
	'UserCountry_country_jm' => 'Jamaika',
	'UserCountry_country_jo' => 'Ürdün',
	'UserCountry_country_jp' => 'Japonya',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kırgızistan',
	'UserCountry_country_kh' => 'Kamboçya',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komoros',
	'UserCountry_country_kn' => 'Saint Kitts ve Nevis',
	'UserCountry_country_kp' => 'Kore Demokratik Halk Cumhuriyeti',
	'UserCountry_country_kr' => 'Kore Cumhuriyeti',
	'UserCountry_country_kw' => 'Kuveyt',
	'UserCountry_country_ky' => 'Cayman Adaları',
	'UserCountry_country_kz' => 'Kazakistan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lübnan',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Lihtenştayn',
	'UserCountry_country_lt' => 'Litvanya',
	'UserCountry_country_lu' => 'Lüksemburg',
	'UserCountry_country_lv' => 'Letonya',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Fas',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_md' => 'Moldovya',
	'UserCountry_country_me' => 'Karadağ',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshall Adaları',
	'UserCountry_country_mk' => 'Makedonya',
	'UserCountry_country_mn' => 'Moğolistan',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mv' => 'Maldivler',
	'UserCountry_country_mx' => 'Meksika',
	'UserCountry_country_my' => 'Malezya',
	'UserCountry_country_mz' => 'Mozambik',
	'UserCountry_country_nc' => 'Yeni Kaledonya',
	'UserCountry_country_nl' => 'Hollanda',
	'UserCountry_country_no' => 'Norveç',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nz' => 'Yeni Zelanda',
	'UserCountry_country_pg' => 'Papua Yeni Gine',
	'UserCountry_country_ph' => 'Filipinler',
	'UserCountry_country_pl' => 'Polonya',
	'UserCountry_country_pt' => 'Portekiz',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Katar',
	'UserCountry_country_ro' => 'Romanya',
	'UserCountry_country_rs' => 'Sırbistan',
	'UserCountry_country_ru' => 'Rusya',
	'UserCountry_country_sa' => 'Suudi Arabistan',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'İsveç',
	'UserCountry_country_sf' => 'Finlandiya',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_si' => 'Slovenya',
	'UserCountry_country_sk' => 'Slovakya',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Suriye',
	'UserCountry_country_td' => 'Çad',
	'UserCountry_country_th' => 'Tayland',
	'UserCountry_country_tj' => 'Tacikistan',
	'UserCountry_country_tl' => 'Doğu Timor',
	'UserCountry_country_tm' => 'Türkmenistan',
	'UserCountry_country_tn' => 'Tunus',
	'UserCountry_country_tr' => 'Türkiye',
	'UserCountry_country_tt' => 'Trinidad ve Tobago',
	'UserCountry_country_ua' => 'Ukrayna',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Birleşik Krallık',
	'UserCountry_country_um' => 'Amerika Birleşik Devletleri Küçük Dış Adaları',
	'UserCountry_country_us' => 'Birleşik Devletler',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Özbekistan',
	'UserCountry_country_va' => 'Vatikan',
	'UserCountry_country_vc' => 'Saint Vincent ve Grenadinler',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_za' => 'Güney Afrika',
	'UserCountry_country_zm' => 'Zambiya',
	'UserCountry_country_zw' => 'Zimbabve',
	'UserCountry_country_o1' => 'Diğer Ükle',
	'UserCountry_continent_eur' => 'Avrupa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_ant' => 'Antaktika',
	'UserCountry_continent_asi' => 'Asya',
	'UserCountry_continent_amn' => 'Kuzey Amerika',
	'UserCountry_continent_amc' => 'Merkez Amerika',
	'UserCountry_continent_ams' => 'Güney Amerika',
	'UserCountry_continent_oce' => 'Okyanusya',
	'UserCountryMap_map' => 'harita',
	'UserCountryMap_worldMap' => 'dünya haritasi',
	'UserCountryMap_toggleFullscreen' => 'Geniş tüm ekran',
	'UserSettings_PluginDescription' => 'Çeşitli kullanıcı rapor ayalari: Tarayıcı, Tarayıcı Ailesi, İşletim Sistemi, Eklentiler, Çözünürlük, Genel Ayarlar.',
	'UserSettings_VisitorSettings' => 'Ziyaretçi Ayarlari',
	'UserSettings_BrowserFamilies' => 'Tarayıcı aileleri',
	'UserSettings_Browsers' => 'Tarayıcılar',
	'UserSettings_Plugins' => 'Eklentiler',
	'UserSettings_Configurations' => 'Konfigürasyonları',
	'UserSettings_OperatingSystems' => 'İşletim sistemleri',
	'UserSettings_Resolutions' => 'Çözünürlükler',
	'UserSettings_WideScreen' => 'Geniş ekran',
	'UserSettings_ColumnBrowserFamily' => 'Tarayıcı ailesi',
	'UserSettings_ColumnBrowser' => 'Tarayıcı',
	'UserSettings_ColumnPlugin' => 'Eklenti',
	'UserSettings_ColumnConfiguration' => 'Konfigürasyon',
	'UserSettings_ColumnOperatingSystem' => 'İşletim sistemi',
	'UserSettings_ColumnResolution' => 'Çözünürlük',
	'UserSettings_ColumnTypeOfScreen' => 'Ekran seçimi',
	'UserSettings_WidgetResolutions' => 'Ekran çözünürlükleri',
	'UserSettings_WidgetBrowsers' => 'Ziyaretçi tarayıcılari',
	'UserSettings_WidgetPlugins' => 'Eklenti Listesi',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Not: Hedeflenen eklenti Internet Explorer çalışmamaktadir. Bu not/rapor sadece IE içindir.',
	'UserSettings_WidgetWidescreen' => 'Normal / Geniş ekran',
	'UserSettings_WidgetOperatingSystems' => 'İşletim sistemleri',
	'UserSettings_WidgetGlobalVisitors' => 'Global ziyaretçi konfikasyonu',
	'UserSettings_SubmenuSettings' => 'Ayarlar',
	'UsersManager_PluginDescription' => 'Piwik Kullanıcılar Yönetimi: yeni kullanıcı ekle, izinlerini güncelleştirmek, varolan bir düzenleme. Tüm eylemler API üzerinden de mevcuttur.',
	'UsersManager_UsersManagement' => 'Kullanıcı Yönetimleri',
	'UsersManager_UsersManagementMainDescription' => 'Yeni kullanıcı yaratın yada var olan kullanıcıyı güncelleyin. Yukaridaki izinleri ayarlayabilirsiniz.',
	'UsersManager_ManageAccess' => 'Erişim Yöneticisi',
	'UsersManager_Sites' => 'Websiteler',
	'UsersManager_AllWebsites' => 'Tüm Websiteler',
	'UsersManager_ApplyToAllWebsites' => 'Tüm websitelere uygula',
	'UsersManager_User' => 'Kullanıcı',
	'UsersManager_PrivNone' => 'Erişim Yok',
	'UsersManager_PrivView' => 'Göster',
	'UsersManager_PrivAdmin' => 'Yönetici',
	'UsersManager_ChangeAllConfirm' => 'Tüm websitelerin \'%s\' izinlerini değiştirmektesiniz, emin misiniz?',
	'UsersManager_Password' => 'Şifre',
	'UsersManager_Email' => 'Eposta',
	'UsersManager_Alias' => 'Diğer Ad',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Süper Kullanıcı adı değiştirilemez.',
	'UsersManager_ReportToLoadByDefault' => 'Varsayılan rapor yüklendi.',
	'UsersManager_ReportDateToLoadByDefault' => 'Varsayılarak yüklenen rapor tarihi',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'İsimsiz ziyaretçiler için, varsayılan yüklenen raporlar',
	'UsersManager_ExcludeVisitsViaCookie' => 'Sizin ziyaretlerinizi çerezlerle (cookies) hariç tutun',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sSizin ziyaretleriniz Piwik tarafından %s hariç tutulmuyor%s (Piwik tarayınızdaki çerezleri bulamamiştir. O nedenle hariç tutulmuyorsunuz).',
	'UsersManager_YourVisitsAreNotIgnored' => '%sSizin ziyaretleriniz Piwik tarafından hariç tutulmuyor%s (Piwik tarayınızdaki çerezleri bulamamiştir. O nedenle hariç tutulmuyorsunuz).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Çerezleri silmek ve sizin ziyaretlerinizi takip etmek için burayi tıklayınız',
	'UsersManager_Edit' => 'Düzenle',
	'UsersManager_AddUser' => 'Yeni kullanıcı ekle',
	'UsersManager_MenuUsers' => 'Kullanıcılar',
	'UsersManager_MenuUserSettings' => 'Kullanıcı ayarlari',
	'UsersManager_MenuAnonymousUserSettings' => 'İsimsiz kullanıcı ayarlari',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Not: Sizin isimsiz ziyaretçiler için erişilebilecek websitesi yok, aşağidaki ayarları kullanımda değil.',
	'UsersManager_ChangePassword' => 'Şifre değiştir',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Şifrenizi değiştirmek istiyorsaniz eğer doldurunuz, aksi halde değiştirmeyecekseniz boş bırakınız.',
	'UsersManager_TypeYourPasswordAgain' => 'Yeni parolanizi yeniden yazınız',
	'UsersManager_TheLoginScreen' => 'Giriş ekranı',
	'UsersManager_DeleteConfirm_js' => '%s kullanıcısını silmekten emin misiniz?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Kullanıcı adınız değiştirilemez.',
	'UsersManager_ExceptionInvalidEmail' => 'Girilen E-posta geçerli bir formatı yoktur.',
	'UsersManager_ExceptionDeleteDoesNotExist' => '\'%s\' kullanıcısı bazı nedenlerle silinemez.',
	'UsersManager_ExceptionAdminAnonymous' => '\'Misafir\' kullanıcıya \'yönetici\' ünvani verilemez.',
	'UsersManager_ExceptionUserDoesNotExist' => '\'%s\' Kullanıcı yok.',
	'VisitorGenerator_AreYouSure' => 'Sahte ziyaretçi oluşturmak isteğinizden emin misiniz?',
	'VisitorGenerator_ChoiceYes' => 'Evet, eminim!',
	'VisitorGenerator_Submit' => 'Gönder',
	'VisitorGenerator_SelectWebsite' => 'Website seçimi',
	'VisitsSummary_PluginDescription' => 'Genel analiz sonuçlarını rapor eder: ziyaretler,tekil ziyaretçiler,etkinlik sayıları,sıçrama oranı vb.',
	'VisitsSummary_VisitsSummary' => 'Özeri gör',
	'VisitsSummary_NbVisits' => '%s ziyaret',
	'VisitsSummary_NbUniqueVisitors' => '%s tekil ziyaretçiler',
	'VisitsSummary_NbActionsDescription' => 'Etkinlik sayısı %s (sayfa gösterimi, dosya indirme, dış linkler)',
	'VisitsSummary_MaxNbActions' => 'Bir ziyarette yapılan max etkinlik %s',
	'VisitsSummary_NbVisitsBounced' => '%s ziyaret sıçrama yaşadı (ziyaretçi 1 sayfaya baktıktan sonra siteyi terketti )',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Son %s değerlendirmesi',
	'VisitsSummary_GenerateTime' => 'sayfa %s saniyede oluşturulmuştur.',
	'VisitsSummary_GenerateQueries' => '%s sorgu çalıştırılmıştır.',
	'VisitsSummary_WidgetLastVisits' => 'Son ziyaret grafiği',
	'VisitsSummary_WidgetVisits' => 'Ziyaret özeti',
	'VisitsSummary_WidgetLastVisitors' => 'Son tekil ziyaretçi grafiği',
	'VisitsSummary_WidgetOverviewGraph' => 'Grafiklere genel bakış',
	'VisitsSummary_SubmenuOverview' => 'Genel Bakış',
	'VisitTime_LocalTime' => 'Yerel saat başına ziyaretler',
	'VisitTime_ServerTime' => 'yerel sunucu başına ziyaretler',
	'VisitTime_ColumnServerTime' => 'Sunucu saati',
	'VisitTime_ColumnLocalTime' => 'Yerel saat',
	'VisitTime_NHour' => '%sh',
	'Widgetize_PluginDescription' => 'Eklenti, istediğiniz Piwik Widget\'ı blogunuzda, sitenizde ya da igoogle ve Netvibes\'da kullanmanızı sağlar.',
);
